@@ -5,7 +5,7 @@ use utf8;
 
 package Neo4j::Driver::Type::Point;
 # ABSTRACT: Represents a Neo4j spatial point value
-$Neo4j::Driver::Type::Point::VERSION = '0.43';
+$Neo4j::Driver::Type::Point::VERSION = '0.44';
 
 # For documentation, see Neo4j::Driver::Types.
 
@@ -45,31 +45,3 @@ sub coordinates {
 
 
 1;
-
-__END__
-
-=pod
-
-=encoding UTF-8
-
-=head1 NAME
-
-Neo4j::Driver::Type::Point - Represents a Neo4j spatial point value
-
-=head1 VERSION
-
-version 0.43
-
-=head1 AUTHOR
-
-Arne Johannessen (L<AJNN|https://metacpan.org/author/AJNN>)
-
-=head1 COPYRIGHT AND LICENSE
-
-This software is Copyright (c) 2016-2024 by Arne Johannessen.
-
-This is free software; you can redistribute it and/or modify it under
-the terms of the Artistic License 2.0 or (at your option) the same terms
-as the Perl 5 programming language system itself.
-
-=cut
